"""
    Main file for APP_NAME_PLACEHOLDER

    File name: main.py
    Author: APP_AUTHOR_PLACEHOLDER
    Date created: DATE_PLACEHOLDER
    Date last modified: DATE_PLACEHOLDER
"""

import nx


def main():
    """
    The main loop
    """
    print('Hello world!')


if __name__ == '__main__':
    main()
