/**
 *  @file    main.c
 *  @author  APP_AUTHOR_PLACEHOLDER
 *  @date    DATE_PLACEHOLDER
 *  @version 0.0.1
 *
 *  This is the main file for APP_NAME_PLACEHOLDER.
 *  Original example file by libtransistor.
 */

#include<libtransistor/nx.h>

#include<stdio.h>

int main() {
	printf("Hello, world!\n");
	return 0;
}
